@@ -1,6 +1,6 @@
 /*
     Eiciel - GNOME editor of ACL file permissions.
-    Copyright (C) 2004-2014 Roger Ferrer Ibez
+    Copyright (C) 2004-2019 Roger Ferrer Ibáñez
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,15 +20,23 @@
 #ifndef EICIEL_NAUTILUS_PAGE_HPP
 #define EICIEL_NAUTILUS_PAGE_HPP
 
-#define NAUTILUS_TYPE_EICIEL_PROPERTIES_PAGE         (nautilus_eiciel_properties_page_get_type ())
-#define NAUTILUS_EICIEL_PROPERTIES_PAGE(obj)         (GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_EICIEL_PROPERTIES_PAGE, NautilusEicielPropertiesPage))
-#define NAUTILUS_EICIEL_PROPERTIES_PAGE_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_EICIEL_PROPERTIES_PAGE, NautilusEicielPropertiesPageClass))
-#define NAUTILUS_IS_EICIEL_PROPERTIES_PAGE(obj)      (GTK_CHECK_TYPE ((obj), NAUTILUS_TYPE_EICIEL_PROPERTIES_PAGE))
-#define NAUTILUS_IS_EICIEL_PROPERTIES_PAGE_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_EICIEL_PROPERTIES_PAGE))
+#define NAUTILUS_TYPE_EICIEL_PROPERTIES_PAGE \
+    (nautilus_eiciel_properties_page_get_type())
+#define NAUTILUS_EICIEL_PROPERTIES_PAGE(obj)                     \
+    (GTK_CHECK_CAST((obj), NAUTILUS_TYPE_EICIEL_PROPERTIES_PAGE, \
+        NautilusEicielPropertiesPage))
+#define NAUTILUS_EICIEL_PROPERTIES_PAGE_CLASS(klass)                     \
+    (GTK_CHECK_CLASS_CAST((klass), NAUTILUS_TYPE_EICIEL_PROPERTIES_PAGE, \
+        NautilusEicielPropertiesPageClass))
+#define NAUTILUS_IS_EICIEL_PROPERTIES_PAGE(obj) \
+    (GTK_CHECK_TYPE((obj), NAUTILUS_TYPE_EICIEL_PROPERTIES_PAGE))
+#define NAUTILUS_IS_EICIEL_PROPERTIES_PAGE_CLASS(klass) \
+    (GTK_CHECK_CLASS_TYPE((klass), NAUTILUS_TYPE_EICIEL_PROPERTIES_PAGE))
 
 G_BEGIN_DECLS
 
-typedef struct NautilusEicielPropertiesPageDetails NautilusEicielPropertiesPageDetails;
+typedef struct NautilusEicielPropertiesPageDetails
+    NautilusEicielPropertiesPageDetails;
 
 typedef struct {
     GtkVBox parent;
