@@ -1,6 +1,6 @@
 /*
     Eiciel - GNOME editor of ACL file permissions.
-    Copyright (C) 2004-2010 Roger Ferrer Ibez
+    Copyright (C) 2004-2019 Roger Ferrer Ibáñez
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,18 +22,17 @@
 
 #include "acl_element_kind.hpp"
 
-class ModelLlistaParticipant : public Gtk::TreeModel::ColumnRecord
-{
-	public:
-		ModelLlistaParticipant()
-		{
-			add(_icon);
-			add(_participant_name);
-            add(_entry_kind);
-		}
-		Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixbuf> > _icon;
-		Gtk::TreeModelColumn<Glib::ustring> _participant_name;
-        Gtk::TreeModelColumn<ElementKind> _entry_kind;
+class ParticipantListModel : public Gtk::TreeModel::ColumnRecord {
+public:
+    ParticipantListModel()
+    {
+        add(_icon);
+        add(_participant_name);
+        add(_entry_kind);
+    }
+    Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixbuf>> _icon;
+    Gtk::TreeModelColumn<Glib::ustring> _participant_name;
+    Gtk::TreeModelColumn<ElementKind> _entry_kind;
 };
 
 #endif
