@@ -1,6 +1,6 @@
 /*
    Eiciel - GNOME editor of ACL file permissions.
-   Copyright (C) 2004-2014 Roger Ferrer Ibez
+   Copyright (C) 2004-2019 Roger Ferrer Ibáñez
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,17 +22,16 @@
 #include <config.hpp>
 #include <gtkmm.h>
 
-class XAttrListModel : public Gtk::TreeModel::ColumnRecord
-{
-    public:
-        XAttrListModel()
-        {
-            add(_attribute_name);
-            add(_attribute_value);
-        }
+class XAttrListModel : public Gtk::TreeModel::ColumnRecord {
+public:
+    XAttrListModel()
+    {
+        add(_attribute_name);
+        add(_attribute_value);
+    }
 
-        Gtk::TreeModelColumn<Glib::ustring> _attribute_name;
-        Gtk::TreeModelColumn<Glib::ustring> _attribute_value;
+    Gtk::TreeModelColumn<Glib::ustring> _attribute_name;
+    Gtk::TreeModelColumn<Glib::ustring> _attribute_value;
 };
 
 #endif
